@@ -2,7 +2,7 @@ package QMake::Project;
 use strict;
 use warnings;
 
-our $VERSION = '0.83';
+our $VERSION = '0.84';
 
 use Carp;
 use English qw(-no_match_vars);
@@ -96,19 +96,44 @@ sub make
     return $self->{ _make };
 }
 
-sub _qmake
+sub set_qmake
+{
+    my ($self, $qmake) = @_;
+
+    $self->{ _qmake } = $qmake;
+
+    return;
+}
+
+sub qmake
 {
     my ($self) = @_;
-    if (!$self->{ _qmake }) {
-        my @qmakes = qw(qmake-qt5 qmake-qt4 qmake);
+
+    return $self->{ _qmake };
+}
+
+sub _find_qmake
+{
+    my ($self) = @_;
+    if (!$self->{ _found_qmake }) {
+        my @qmakes = qw(qmake qmake-qt5 qmake-qt4);
         foreach my $qmake (@qmakes) {
             if (my $found = which( $qmake )) {
-                $self->{ _qmake } = $found;
+                $self->{ _found_qmake } = $found;
                 last;
             }
         }
     }
-    return $self->{ _qmake };
+    return $self->{ _found_qmake };
+}
+
+sub _qmake
+{
+    my ($self) = @_;
+    if (my $qmake = $self->qmake()) {
+        return $qmake;
+    }
+    return $self->_find_qmake();
 }
 
 # Returns a reasonable default make command based on the platform.
@@ -780,7 +805,7 @@ QMake::Project - evaluate qmake project files
 
   use QMake::Project;
 
-  # Load a project from a qmake-generated Makefile
+  # Load a project from a .pro file
   my $prj = QMake::Project->new( 'test.pro' );
 
   # Perform arbitrary tests; may be anything usable from a qmake scope
@@ -850,8 +875,8 @@ This is accomplished by delayed evaluation.
 
 Essentially, repeated calls to the B<test> or B<values> functions
 will not result in any qmake runs, until one of the values returned
-by these functions is actually used.  This is accomplished by
-returning blessed values with overloaded conversions.
+by these functions is used.  This is accomplished by returning
+deferred values via L<Scalar::Defer>.
 
 For example, consider this code:
 
@@ -1004,6 +1029,14 @@ Get or set the "make" binary (with no arguments) to be used for parsing
 the makefile.  It should rarely be required to use these functions, as
 there is a reasonable default.
 
+=item B<qmake>()
+
+=item B<set_qmake>( QMAKE )
+
+Get or set the "qmake" binary (with no arguments).
+If unset (the default), the first existing 'qmake', 'qmake-qt5' or
+'qmake-qt4' command in PATH will be used.
+
 =item B<die_on_error>()
 
 =item B<set_die_on_error>( BOOL )
